@@ -36,6 +36,61 @@ class CommonCheckWidget(
         '''
         jsii.create(CommonCheckWidget, self, [request_id])
 
+    @jsii.member(jsii_name="compareToken")
+    def compare_token(
+        self,
+        token_expected: typing.Any,
+        token_compared: typing.Any,
+    ) -> builtins.bool:
+        '''
+        :param token_expected: -
+        :param token_compared: -
+        '''
+        return typing.cast(builtins.bool, jsii.invoke(self, "compareToken", [token_expected, token_compared]))
+
+    @jsii.member(jsii_name="generateHashFromData")
+    def generate_hash_from_data(self, data: typing.Any) -> builtins.str:
+        '''
+        :param data: -
+        '''
+        return typing.cast(builtins.str, jsii.ainvoke(self, "generateHashFromData", [data]))
+
+    @jsii.member(jsii_name="generateJWTFromData")
+    def generate_jwt_from_data(self, data: typing.Any) -> builtins.str:
+        '''
+        :param data: -
+        '''
+        return typing.cast(builtins.str, jsii.ainvoke(self, "generateJWTFromData", [data]))
+
+    @jsii.member(jsii_name="generatePayloadJsonStr")
+    def generate_payload_json_str(
+        self,
+        flight_number: builtins.str,
+        flight_date: builtins.str,
+        first_name: builtins.str,
+        last_name: builtins.str,
+        date_of_birth: builtins.str,
+        passport: builtins.str,
+        nationality: builtins.str,
+    ) -> builtins.str:
+        '''
+        :param flight_number: -
+        :param flight_date: -
+        :param first_name: -
+        :param last_name: -
+        :param date_of_birth: -
+        :param passport: -
+        :param nationality: -
+        '''
+        return typing.cast(builtins.str, jsii.invoke(self, "generatePayloadJsonStr", [flight_number, flight_date, first_name, last_name, date_of_birth, passport, nationality]))
+
+    @jsii.member(jsii_name="generateTokenFromData")
+    def generate_token_from_data(self, data: typing.Any) -> builtins.str:
+        '''
+        :param data: -
+        '''
+        return typing.cast(builtins.str, jsii.ainvoke(self, "generateTokenFromData", [data]))
+
     @jsii.member(jsii_name="getErrorMessage")
     def get_error_message(self, error_obj: typing.Any) -> typing.Any:
         '''
