@@ -19,7 +19,7 @@ describe('API Tests', function() {
                   .then(function(result) {
                     const str = JSON.stringify(result)
                     console.log(str)
-                     expect(str).to.equal('{"validToEnter":true,"code":"2000","errors":[],"metadata":{"info":[{"type":"Verified"}]}}')
+                     expect(str).to.equal('{"validToEnter":true,"code":"SUCCESS","errors":[],"metadata":{}}')
                      resolve()
                   });
              });
@@ -35,7 +35,7 @@ describe('API Tests', function() {
                   .then(function(result) {
                     const str = JSON.stringify(result)
                     console.log(str)
-                     expect(str).to.equal('{"validToEnter":false,"code":"4000","errors":[{"type":"Test Collection Date","value":"2021-07-29T13:15:42.443Z","description":"Covid Test must be obtained 3 days before departure"}],"metadata":{}}')   
+                     expect(str).to.equal('{"validToEnter":false,"code":"NOT_VALID_TO_ENTER","errors":[{"type":"Test Collection Date","value":"2021-07-29T13:15:42.443Z","description":"Covid Test must be obtained 3 days before departure"}],"metadata":{}}')   
                      resolve()
                   });
              });
@@ -51,7 +51,7 @@ describe('API Tests', function() {
                   .then(function(result) {
                     const str = JSON.stringify(result)
                     console.log(str)
-                     expect(str).to.equal('{"validToEnter":false,"code":"6000","errors":[{"type":"Unsupported document(s)","description":"Currently we only support documents with digital certificate QR codes to be verified online."}],"metadata":{}}')  
+                     expect(str).to.equal('{"validToEnter":false,"code":"QR_UNREADABLE_OR_UNDETECTED","metadata":{}}')  
                      resolve()
                   });
              });
